<?php

/**
 * @file
 */

namespace Drupal\smsc\D7Helper;


/**
 * Class D7Helper
 *
 * @package Drupal\smsc\D7Helper
 */
class D7Helper {

  /**
   * Drupal8-style config.
   *
   * @var array Array with key-value paires config.
   */
  protected $config;

  /**
   * D7Helper constructor.
   */
  public function __construct() {
    $config = variable_get('smsc_config', [
      'login'    => '',
      'psw'      => '',
      'host'     => '',
      'sender'   => '',
      'translit' => '',
    ]);

    $this->config = $config;
  }

  /**
   * @return array
   */
  public function getConfig() {
    return $this->config;
  }

  /**
   * @param array $config
   *
   * @return D7Helper
   */
  public function setConfig(array $config) {
    $this->config = $config;

    return $this;
  }

  /**
   * Get value.
   *
   * @param string $key
   *
   * @return mixed
   */
  public function get($key = '') {
    $config = $this->getConfig();

    return $config[$key];
  }

  /**
   * Set value to config.
   *
   * @param string $key
   * @param mixed  $value
   *
   * @return \Drupal\smsc\D7Helper\D7Helper
   */
  public function set($key, $value) {
    $config = $this->getConfig();

    $config[$key] = $value;

    return $this->setConfig($config);
  }

  /**
   * Save config.
   */
  public function save() {
    variable_set('smsc_config', $this->getConfig());
  }

  /**
   * {@inheritdoc}
   */
  public function hasSettings() {
    return (bool) (!empty($this->get('login')) && !empty($this->get('psw')));
  }
}
